* Plug in directory
cd "...\Replication files\"

* Log file
capture log close
log using Consensus&DQ.log, replace


*		************************************************************************		*
*		************************************************************************		*
*		  File:				Consensus&DQ.do												*
*		  Date:				April 2015													*
*		  Author:			MG															*
*		  Purpose:			Taking the Multidimensionality of Democracy Seriously		*
*		  Input file:		Consensus&DQ.dta.dta										*
*		  Log file:			Consensus&DQ.log											*
*		  Data output:		None														*
*		  Machine:			Office laptop												*
*		  Stata version:	11.2														*
*		************************************************************************		*
*		************************************************************************		*



*******************
** Install packages
*******************

findit lean2 /* Manual installation */



************
** Load data
************

use "Consensus&DQ.dta", replace



**********
** Table 1
**********

* Principal factor analysis, w/o central bank independence and constitutional rigidity
fac party cab exeleg elec intgr fed dec bic jud, mineigen(1)
screeplot
* Rotating the results
rotate, blanks(.3)
estimates store factor

* Version including all 11 indicators (not reported)
* Principal factor analysis, including central bank independence and constitutional rigidity
fac party cab exeleg elec intgr fed dec bic const jud cent, mineigen(1)
screeplot
* Rotating the results
rotate, blanks(.3)


****************************
** Generate additive indices
****************************

* First, standardize 9 indicators
foreach var of varlist party cab exeleg elec intgr fed dec bic jud {
egen n`var'=std(`var')
}
* Then add standardized indicators belonging to the two respective dimensions
generate exep=nparty+ncab+nexeleg+nelec+nintgr
generate fedu=nfed+ndec+nbic+njud
* Finally, standardize the two dimensions
egen exepar=std(exep)
label variable exepar "Executives-Parties"
egen feduni=std(fedu)
label variable feduni "Federal-Unitary"

* Tidy up dataset
drop nparty - fedu



***********
** Figure 6
***********

* Generate variable indicating the clock position of each label
gen clockpos = 3
replace clockpos = 7 if code == "DEU"
replace clockpos = 9 if code == "LTU"
replace clockpos = 4 if code == "SVK"
replace clockpos = 9 if code == "LVA"
replace clockpos = 6 if code == "LUX"
replace clockpos = 9 if code == "ISL"
replace clockpos = 12 if code == "IRL"
replace clockpos = 6 if code == "BGR"
replace clockpos = 4 if code == "EST"

scatter feduni exepar, ///
	xscale(range(-2.5 2.5)) yscale(range(-2.3 3.1)) ///
	ylabel(-2(1)3, nogrid labsize(medsmall)) xlabel(, nogrid labsize(medsmall)) ///
	xline(0, lwidth(thin)) yline(0, lwidth(thin)) ///
	mlabel(code) mlabvposition(clockpos) ///
	xtitle(, size(medium)) ytitle(, size(medium)) ///
	text(2.8 -1.4 "Majoritarian-Decentralized", placement(c) size(medsmall) justification(left) box fcolor(gs14) margin(small)) ///
	text(2.8 1.4 "Proportional-Decentralized", placement(c) size(medsmall) justification(left) box fcolor(gs14) margin(small)) ///
	text(-2 -1.4 "Majoritarian-Unitary", placement(c) size(medsmall) justification(left) box fcolor(gs14) margin(small)) ///
	text(-2 1.4 "Proportional-Unitary", placement(c) size(medsmall) justification(left) box fcolor(gs14) margin(small)) ///
	ysize(8) xsize(12) scheme(lean2) 
graph export "Fig6.tif", replace



***********
** Figure 7
***********

* Preparations
* Generate interaction term
gen exexfed = exepar * feduni
label var exexfed "Executives-Parties X Federal-Unitary"

* Standardize control variables
egen min_GDPcap = min(GDPcap)
egen max_GDPcap = max(GDPcap)
egen min_infl = min(infl)
egen max_infl = max(infl)
egen min_lifex = min(lifex)
egen max_lifex = max(lifex)
egen min_edux = min(edux)
egen max_edux = max(edux)

gen GDPcap_st = (GDPcap - min_GDPcap)/(max_GDPcap - min_GDPcap)
gen infl_st = (infl - min_infl)/(max_infl - min_infl)
gen lifex_st = (lifex - min_lifex)/(max_lifex - min_lifex)
gen edux_st = (edux - min_edux)/(max_edux - min_edux)

label variable GDPcap_st "GDP per capita (std.)"
label variable infl_st "Inflation (std.)"
label variable lifex_st "Life expectancy (std.)"
label variable edux_st "Education (std.)"

* Tidy up
drop min_GDPcap - max_edux

* Control variable selection: choose those two with strongest relation in unconditional model w/o interaction term
* Government capability --> GDP p. cap & education
reg govcap exepar feduni GDPcap_st edux_st  lifex_st infl_st, robust

* Transparency --> education & inflation
reg transpar exepar feduni GDPcap_st edux_st  lifex_st infl_st, robust

* Participation --> education & life expectancy index
reg particip exepar feduni GDPcap_st edux_st  lifex_st infl_st, robust

* Representation --> education & inflation
reg repres_wo_gallagher exepar feduni GDPcap_st edux_st  lifex_st infl_st, robust


* Interaction effect on government capability
qui: reg govcap exepar feduni exexfed GDPcap_st edux_st, robust
estimates store govcap
run "Interaction_plot.do"
graph export "Fig7_govcap.tif", replace

* Interaction effect on transparency
qui: reg transpar exepar feduni exexfed edux_st infl_st, robust
estimates store transpar
run "Interaction_plot.do"
graph export "Fig7_transpar.tif", replace

* Interaction effect on participation
qui: reg particip exepar feduni exexfed edux_st lifex_st, robust
estimates store particip
run "Interaction_plot.do"
graph export "Fig7_particip.tif", replace

* Interaction effect on representation
qui: reg repres_wo_gallagher exepar feduni exexfed edux_st infl_st, robust
estimates store repres
run "Interaction_plot.do"
graph export "Fig7_repres.tif", replace



************
** Table A.1
************

estout govcap transpar particip repres, ///
	cells(b(fmt(%9.2f) nostar) ci_l ci_u) ///
	stats(p r2 N, fmt(%9.2f %9.2f %9.0g) labels("Prob > F" "R-squared")) ///
	drop(_cons) ///
	varwidth(30) modelwidth(16) ///
	label mlabels(, depvars)


 
*************************************************************
** Robustness test: Factor scores instead of additive indices
*************************************************************

* Generate factor scores
estimates restore factor
predict f1 f2
label var f1 "Federal-Unitary (factor scores)"
label var f2 "Executives-Parties (factor scores)"

* Generate interaction term
gen f1xf2 = f1 * f2
label var f1xf2 "Executives-Parties (factor scores) X Federal-Unitary (factor scores)"

* Control variable selection: choose those two with strongest relation in unconditional model w/o interaction term
* Government capability --> GDP p. cap & education
reg govcap f2 f1 GDPcap_st edux_st  lifex_st infl_st, robust

* Transparency --> education & inflation
reg transpar f2 f1 GDPcap_st edux_st  lifex_st infl_st, robust

* Participation --> education & life expectancy index
reg particip f2 f1 GDPcap_st edux_st  lifex_st infl_st, robust

* Representation --> education & inflation
reg repres_wo_gallagher f2 f1 GDPcap_st edux_st  lifex_st infl_st, robust


* Interaction effect on government capability
qui: reg govcap f2 f1 f1xf2 GDPcap_st edux_st, robust
run "Interaction_plot.do"

* Interaction effect on transparency
qui: reg transpar f2 f1 f1xf2 edux_st infl_st, robust
run "Interaction_plot.do"

* Interaction effect on participation
qui: reg particip f2 f1 f1xf2 edux_st lifex_st, robust
run "Interaction_plot.do"

* Interaction effect on representation
qui: reg repres_wo_gallagher f2 f1 f1xf2 edux_st infl_st, robust
run "Interaction_plot.do"



*****************
** Close log file
*****************

log close
