
*		************************************************************************		*
*		************************************************************************		*
*		  File:				Interaction_plot.do											*
*		  Date:				April 2015													*
*		  Author:			MG															*
*		  Purpose:			Draw interaction plots for:									*
*							"Taking the Multidimensionality of Democracy Seriously"		*
*		  Input file:		None														*
*		  Log file:			Consensus&DQ.log											*
*		  Data output:		None														*
*		  Machine:			Office laptop												*
*		  Stata version:	11.2														*
*		************************************************************************		*
*		************************************************************************		*


* Generate the values of Z (modifying variable) for which to calculate 
* the marginal effect (and standard errors) of X on Y
set obs 390
gen MV = ((_n-140)/100)


* Grab elements of the coefficient and variance-covariance matrix that are required 
* to calculate the marginal effect and standard errors
matrix b = e(b)
matrix V = e(V)

scalar b1 = b[1,1]
scalar b2 = b[1,2]
scalar b3 = b[1,3]

scalar varb1 = V[1,1]
scalar varb2 = V[2,2]
scalar varb3 = V[3,3]

scalar covb1b3 = V[1,3]
scalar covb2b3 = V[2,3]


* Calculate the marginal effect of X on Y for all MV values of the modifying variable Z
gen conb = b1 + b3 * MV

* Calculate the standard errors for the marginal effect of X on Y for all MV values of the modifying variable Z
gen conse = sqrt(varb1+varb3*(MV^2)+2*covb1b3*MV)

* Generate upper and lower bounds of the 90% confidence interval 
gen a=1.65*conse
gen upper=conb + a
gen lower=conb - a


* Plot marginal effect of X on Y across the desired range of the modifying variable Z, including confidence interval

graph twoway 	(line conb MV, clwidth(medthick) clcolor(black)) ///
				(line upper MV, clpattern(dash) clwidth(medium) clcolor(black)) ///
				(line lower MV, clpattern(dash) clwidth(medium) clcolor(black)), ///
					xscale(range(-1.5 2.6) lwidth(medthin)) yscale(range(-15 20) lwidth(medthin)) ///
					xlabel(-1(1)2, nogrid labsize(medlarge) tlwidth(medthin)) ylabel(-10(10)20, nogrid labsize(medlarge) tlwidth(medthin)) ///  
					yline(0, lwidth(medthin) lcolor(black)) ///
					xtitle("Federal-Unitary Dimension", margin(medium) size(large)) ///
					ytitle("Marginal Effect of" "Executives-Parties Dimension", margin(small) size(large)) ///
					ysize(8) xsize(12) legend(off) scheme(lean2)


* Tidy up
drop MV - lower
